#!/usr/bin/env python

import subprocess
import os
from distutils.core import setup

# Fetch version from git tags, and write to version.py.
# Also, when git is not available (PyPi package), use stored version.py.
version_py = os.path.join(os.path.dirname(__file__), 'version.py')

try:
    version_git = subprocess.check_output(["git", "describe", "--tags"]).rstrip()
except:
    with open(version_py, 'r') as fh:
        version_git = open(version_py).read().strip().split('=')[-1].replace('"','')

version_msg = "# Do not edit this file, pipeline versioning is governed by git tags"
with open(version_py, 'w') as fh:
    fh.write(version_msg + os.linesep + "__version__=" + version_git)

# Source of git tag integration:
# http://blogs.nopcode.org/brainstorm/2013/05/20/pragmatic-python-versioning-via-setuptools-and-git-tags/

setup(name="odswriter",
      version=version_git,
      description="A pure-Python module for writing OpenDocument spreadsheets (similar to csv.writer).",
      author="Michael Mulqueen",
      author_email="michael@mulqueen.me.uk",
      url="https://github.com/mmulqueen/odswriter",
      packages=["odswriter"],
      license="MIT License",
      classifiers=[
          "License :: OSI Approved :: MIT License",
          "Topic :: Office/Business :: Financial :: Spreadsheet"
      ]
     )



